# NOT RUN {
# Download bike trip data for the month of January, 2019, in Bergen
# as CSV or JSON
dl_trips_data(year = 2019, month = 01, city = "Bergen", filetype = "CSV)
dl_trips_data(year = 2019, month = 01, city = "Bergen", filetype = "JSON)
# Download bike trips data for the month of October, 2018, in Trondheim
dl_trips_data(2018, 10, "Trondheim")
# Use "lapply()" to download bike trips data for several months in Oslo
lapply(06:08, dl_trips_data, year = 2018, city = "Oslo")
# }
# NOT RUN {
# }
Run the code above in your browser using DataLab