# NOT RUN {
# Fast read bike trips data for the month of January 2019 in Bergen
bergen_trips <- fread_trips_data(year = 2019, month = 1, city = "Bergen")
# Fast read bike trips data for the month of October 2018 in Trondheim
trondheim_trips <- fread_trips_data(2018, 10, "Trondheim")
# }
# NOT RUN {
# }
Run the code above in your browser using DataLab